==> openjdk-17_17.0.11~7ea.orig.tar.xz: openjdk-17-17.0.11~7ea/test/hotspot/jtreg/gc/arguments/TestUseNUMAInterleaving.java <==
/*
 * Copyright (c) 2014, 2022, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

package gc.arguments;

/**
 * @test TestUseNUMAInterleaving
 * @summary Tests that UseNUMAInterleaving enabled for all collectors by
 * ergonomics, on all platforms when UseNUMA feature is enabled.
 * @bug 8059614
 * @library /test/lib
 * @library /
 * @modules java.base/jdk.internal.misc
 *          java.management
 * @run driver gc.arguments.TestUseNUMAInterleaving
 */
import jdk.test.lib.process.OutputAnalyzer;

public class TestUseNUMAInterleaving {

    public static void main(String[] args) throws Exception {
        ProcessBuilder pb = GCArguments.createTestJvm(
            "-XX:+UseNUMA",
            "-XX:+PrintFlagsFinal",
            "-version");
        OutputAnalyzer output = new OutputAnalyzer(pb.start());

        boolean isNUMAEnabled
                = Boolean.parseBoolean(output.firstMatch(NUMA_FLAG_PATTERN, 1));

        if (isNUMAEnabled) {
            output.shouldMatch("\\bUseNUMAInterleaving\\b.*?=.*?true");
            System.out.println(output.getStdout());
        } else {
            System.out.println(output.firstMatch(NUMA_FLAG_PATTERN));
            System.out.println(output.firstMatch(NUMA_FLAG_PATTERN, 1));
        }
    }

    private static final String NUMA_FLAG_PATTERN = "\\bUseNUMA\\b.*?=.*?([a-z]+)";
}

==> openjdk-24_24~29ea.orig.tar.xz: openjdk-24-24~29ea/test/hotspot/jtreg/gc/arguments/TestUseNUMAInterleaving.java <==
/*
 * Copyright (c) 2014, 2023, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

package gc.arguments;

/**
 * @test TestUseNUMAInterleaving
 * @summary Tests that UseNUMAInterleaving enabled for all collectors by
 * ergonomics, on all platforms when UseNUMA feature is enabled.
 * @bug 8059614
 * @library /test/lib
 * @library /
 * @modules java.base/jdk.internal.misc
 *          java.management
 * @run driver gc.arguments.TestUseNUMAInterleaving
 */
import jdk.test.lib.process.OutputAnalyzer;

public class TestUseNUMAInterleaving {

    public static void main(String[] args) throws Exception {
        OutputAnalyzer output = GCArguments.executeTestJava(
            "-XX:+UseNUMA",
            "-XX:+PrintFlagsFinal",
            "-version");

        boolean isNUMAEnabled
                = Boolean.parseBoolean(output.firstMatch(NUMA_FLAG_PATTERN, 1));

        if (isNUMAEnabled) {
            output.shouldMatch("\\bUseNUMAInterleaving\\b.*?=.*?true");
            System.out.println(output.getStdout());
        } else {
            System.out.println(output.firstMatch(NUMA_FLAG_PATTERN));
            System.out.println(output.firstMatch(NUMA_FLAG_PATTERN, 1));
        }
    }

    private static final String NUMA_FLAG_PATTERN = "\\bUseNUMA\\b.*?=.*?([a-z]+)";
}
